==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QCameraControl_shell.h <==
#ifndef QCAMERACONTROL_SHELL_H
#define QCAMERACONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qcameracontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qcamera.h>
#include <QtJambi/RegistryAPI>


class QCameraControl_shell : public QCameraControl, public QtJambiShellInterface
{
public:
    QCameraControl_shell(QObject* parent0 = nullptr);
    ~QCameraControl_shell() override;

    bool canChangeProperty(QCameraControl::PropertyChangeType changeType0, QCamera::Status status1) const override;
    QCamera::CaptureModes captureMode() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isCaptureModeSupported(QCamera::CaptureModes mode0) const override;
    void setCaptureMode(QCamera::CaptureModes arg__1) override;
    void setState(QCamera::State state0) override;
    QCamera::State state() const override;
    QCamera::Status status() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCameraControl_access : public QCameraControl
{
    jboolean __qt_canChangeProperty_QCameraControl_PropertyChangeType_QCamera_Status_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint changeType0, jint status1) const;
    jint __qt_captureMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isCaptureModeSupported_QCamera_CaptureModes_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0) const;
    void __qt_setCaptureMode_QCamera_CaptureModes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1);
    void __qt_setState_QCamera_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint state0);
    jint __qt_state(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_status(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QCAMERACONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QCameraControl_shell.h <==
#ifndef QCAMERACONTROL_SHELL_H
#define QCAMERACONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qcameracontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qcamera.h>
#include <QtJambi/RegistryAPI>


class QCameraControl_shell : public QCameraControl, public QtJambiShellInterface
{
public:
    QCameraControl_shell(QObject* parent0 = nullptr);
    ~QCameraControl_shell() override;

    bool canChangeProperty(QCameraControl::PropertyChangeType changeType0, QCamera::Status status1) const override;
    QCamera::CaptureModes captureMode() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isCaptureModeSupported(QCamera::CaptureModes mode0) const override;
    void setCaptureMode(QCamera::CaptureModes arg__1) override;
    void setState(QCamera::State state0) override;
    QCamera::State state() const override;
    QCamera::Status status() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCameraControl_access : public QCameraControl
{
    jboolean __qt_canChangeProperty_QCameraControl_PropertyChangeType_QCamera_Status_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint changeType0, jint status1) const;
    jint __qt_captureMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isCaptureModeSupported_QCamera_CaptureModes_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0) const;
    void __qt_setCaptureMode_QCamera_CaptureModes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1);
    void __qt_setState_QCamera_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint state0);
    jint __qt_state_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_status_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QCAMERACONTROL_SHELL_H
